@@ -5,8 +5,10 @@ import (
 	"net/http"
 	"time"
 
-	"github.com/stolostron/multicloud-operators-foundation/cmd/webhook/app/options"
-	"k8s.io/client-go/dynamic"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/webhook/clusterset"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/webhook/useridentity"
+
+	"github.com/open-cluster-management/multicloud-operators-foundation/cmd/webhook/app/options"
 	"k8s.io/client-go/informers"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/client-go/tools/cache"
@@ -22,12 +24,8 @@ func Run(opts *options.Options, stopCh <-chan struct{}) error {
 		klog.Errorf("Error building kube config: %s", err.Error())
 		return err
 	}
-
-	dynamicClient, err := dynamic.NewForConfig(kubeConfig)
-	if err != nil {
-		klog.Errorf("Error building dynamic client: %s", err.Error())
-		return err
-	}
+	kubeConfig.QPS = opts.QPS
+	kubeConfig.Burst = opts.Burst
 
 	kubeClientSet, err := kubernetes.NewForConfig(kubeConfig)
 	if err != nil {
@@ -38,10 +36,13 @@ func Run(opts *options.Options, stopCh <-chan struct{}) error {
 	informerFactory := informers.NewSharedInformerFactory(kubeClientSet, 10*time.Minute)
 	informer := informerFactory.Rbac().V1().RoleBindings()
 
-	ah := &admissionHandler{
-		lister:        informer.Lister(),
-		kubeClient:    kubeClientSet,
-		dynamicClient: dynamicClient,
+	mutatingAh := &useridentity.AdmissionHandler{
+		Lister:                informer.Lister(),
+		SkipOverwriteUserList: opts.SkipOverwriteUserList,
+	}
+
+	validatingAh := &clusterset.AdmissionHandler{
+		KubeClient: kubeClientSet,
 	}
 
 	go informerFactory.Start(stopCh)
@@ -51,8 +52,9 @@ func Run(opts *options.Options, stopCh <-chan struct{}) error {
 		return fmt.Errorf("failed to wait for kubernetes caches to sync")
 	}
 
-	http.HandleFunc("/mutating", ah.serveMutateResource)
-	http.HandleFunc("/validating", ah.serverValidateResource)
+	http.HandleFunc("/mutating", mutatingAh.ServeMutateResource)
+
+	http.HandleFunc("/validating", validatingAh.ServerValidateResource)
 
 	server := &http.Server{
 		Addr:      ":8000",
