@@ -13,7 +13,8 @@ import (
 
 	"github.com/onsi/gomega"
 	clusterv1 "github.com/open-cluster-management/api/cluster/v1"
-	clusterv1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	clusterv1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/utils"
 	"github.com/stretchr/testify/assert"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
@@ -76,17 +77,17 @@ func TestMain(m *testing.M) {
 }
 
 // StartTestManager adds recFn
-func StartTestManager(mgr manager.Manager, g *gomega.GomegaWithT) (chan struct{}, *sync.WaitGroup) {
-	stop := make(chan struct{})
+func StartTestManager(mgr manager.Manager, g *gomega.GomegaWithT) (context.CancelFunc, *sync.WaitGroup) {
+	ctx, cancel := context.WithCancel(context.Background())
 	wg := &sync.WaitGroup{}
 	wg.Add(1)
 
 	go func() {
 		defer wg.Done()
-		g.Expect(mgr.Start(stop)).NotTo(gomega.HaveOccurred())
+		g.Expect(mgr.Start(ctx)).NotTo(gomega.HaveOccurred())
 	}()
 
-	return stop, wg
+	return cancel, wg
 }
 
 func TestControllerReconcile(t *testing.T) {
@@ -101,10 +102,10 @@ func TestControllerReconcile(t *testing.T) {
 
 	SetupWithManager(mgr, nil)
 
-	stopMgr, mgrStopped := StartTestManager(mgr, g)
+	cancel, mgrStopped := StartTestManager(mgr, g)
 
 	defer func() {
-		close(stopMgr)
+		cancel()
 		mgrStopped.Wait()
 	}()
 
@@ -130,7 +131,7 @@ func newAdminRoleObjs() []runtime.Object {
 	return []runtime.Object{
 		&rbacv1.ClusterRole{
 			ObjectMeta: metav1.ObjectMeta{
-				Name: buildClusterRoleName(ManagedClusterName, "admin"),
+				Name: utils.GenerateClusterRoleName(ManagedClusterName, "admin"),
 			},
 			Rules: nil,
 		},
@@ -138,6 +139,7 @@ func newAdminRoleObjs() []runtime.Object {
 }
 
 func TestReconcile(t *testing.T) {
+	ctx := context.Background()
 	tests := []struct {
 		name              string
 		existingObjs      []runtime.Object
@@ -239,7 +241,7 @@ func TestReconcile(t *testing.T) {
 			}
 			svrc.kubeClient.CoreV1().Namespaces().Create(context.TODO(), clusterNamespace, metav1.CreateOptions{})
 
-			res, err := svrc.Reconcile(test.req)
+			res, err := svrc.Reconcile(ctx, test.req)
 			validateError(t, err, test.expectedErrorType)
 			if test.requeue {
 				assert.Equal(t, res.Requeue, true)
