@@ -7,8 +7,8 @@ import (
 	"net"
 	"reflect"
 
-	"github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
-	"github.com/stolostron/multicloud-operators-foundation/pkg/klusterlet/log/drivers"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	"github.com/open-cluster-management/multicloud-operators-foundation/pkg/klusterlet/log/drivers"
 	"k8s.io/client-go/kubernetes"
 	certutil "k8s.io/client-go/util/cert"
 	"k8s.io/klog"
@@ -83,7 +83,7 @@ func (k *Agent) RefreshServerIfNeeded(clusterInfo *v1beta1.ManagedClusterInfo) {
 	if k.server.isShutDown() {
 		return
 	}
-
+	klog.Infof("refresh server: %v\n", caData)
 	go k.server.refresh(caData, pool)
 }
 
