@@ -3,8 +3,8 @@ package e2e
 import (
 	"github.com/onsi/ginkgo"
 	"github.com/onsi/gomega"
-	clusterinfov1beta1 "github.com/stolostron/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
-	"github.com/stolostron/multicloud-operators-foundation/test/e2e/util"
+	clusterinfov1beta1 "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/internal.open-cluster-management.io/v1beta1"
+	"github.com/open-cluster-management/multicloud-operators-foundation/test/e2e/util"
 
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
@@ -19,7 +19,7 @@ var _ = ginkgo.Describe("Testing ManagedClusterInfo", func() {
 	ginkgo.Context("Get ManagedClusterInfo", func() {
 		ginkgo.It("should get a ManagedClusterInfo successfully in cluster", func() {
 			gomega.Eventually(func() bool {
-				exists, err := util.HasResource(dynamicClient, clusterInfoGVR, managedClusterName, managedClusterName)
+				exists, err := util.HasResource(dynamicClient, clusterInfoGVR, defaultManagedCluster, defaultManagedCluster)
 				if err != nil {
 					return false
 				}
@@ -27,9 +27,20 @@ var _ = ginkgo.Describe("Testing ManagedClusterInfo", func() {
 			}, eventuallyTimeout, eventuallyInterval).Should(gomega.BeTrue())
 		})
 
+		ginkgo.It("should have node list reported successfully in cluster", func() {
+			gomega.Eventually(func() error {
+				managedClusterInfo, err := util.GetResource(dynamicClient, clusterInfoGVR, defaultManagedCluster, defaultManagedCluster)
+				if err != nil {
+					return err
+				}
+				// check the ManagedClusterInfo status
+				return util.CheckNodeList(managedClusterInfo)
+			}, eventuallyTimeout, eventuallyInterval).ShouldNot(gomega.HaveOccurred())
+		})
+
 		ginkgo.It("should have a valid condition", func() {
 			gomega.Eventually(func() bool {
-				managedClusterInfo, err := util.GetResource(dynamicClient, clusterInfoGVR, managedClusterName, managedClusterName)
+				managedClusterInfo, err := util.GetResource(dynamicClient, clusterInfoGVR, defaultManagedCluster, defaultManagedCluster)
 				if err != nil {
 					return false
 				}
@@ -40,7 +51,7 @@ var _ = ginkgo.Describe("Testing ManagedClusterInfo", func() {
 
 		ginkgo.It("should have valid distributionInfo", func() {
 			gomega.Eventually(func() error {
-				managedClusterInfo, err := util.GetResource(dynamicClient, clusterInfoGVR, managedClusterName, managedClusterName)
+				managedClusterInfo, err := util.GetResource(dynamicClient, clusterInfoGVR, defaultManagedCluster, defaultManagedCluster)
 				if err != nil {
 					return err
 				}
@@ -51,7 +62,7 @@ var _ = ginkgo.Describe("Testing ManagedClusterInfo", func() {
 
 		ginkgo.It("should have valid ClusterID", func() {
 			gomega.Eventually(func() error {
-				managedClusterInfo, err := util.GetResource(dynamicClient, clusterInfoGVR, managedClusterName, managedClusterName)
+				managedClusterInfo, err := util.GetResource(dynamicClient, clusterInfoGVR, defaultManagedCluster, defaultManagedCluster)
 				if err != nil {
 					return err
 				}
@@ -62,15 +73,13 @@ var _ = ginkgo.Describe("Testing ManagedClusterInfo", func() {
 	})
 
 	ginkgo.Context("Delete ManagedClusterInfo Automatically after ManagedCluster is deleted", func() {
-		var testManagedClusterName string
+		var testManagedClusterName = util.RandomName()
 
 		ginkgo.BeforeEach(func() {
-			managedCluster, err := util.CreateManagedCluster(dynamicClient)
+			err := util.ImportManagedCluster(clusterClient, testManagedClusterName)
 			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 
-			testManagedClusterName = managedCluster.GetName()
-
-			//ManagedClusterinfo should exist
+			// ManagedClusterInfo should exist
 			gomega.Eventually(func() bool {
 				existing, err := util.HasResource(dynamicClient, clusterInfoGVR, testManagedClusterName, testManagedClusterName)
 				if err != nil {
@@ -79,12 +88,17 @@ var _ = ginkgo.Describe("Testing ManagedClusterInfo", func() {
 				return existing
 			}, eventuallyTimeout, eventuallyInterval).Should(gomega.BeTrue())
 
-			//Delete the managedcluster
-			err = util.DeleteClusterResource(dynamicClient, util.ManagedClusterGVR, testManagedClusterName)
-			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
+		})
+		ginkgo.AfterEach(func() {
+			err := util.CleanManagedCluster(clusterClient, testManagedClusterName)
+			gomega.Expect(err).ToNot(gomega.HaveOccurred())
 		})
 
-		ginkgo.It("clusterinfo should be deleted automitically.", func() {
+		ginkgo.It("clusterInfo should be deleted automatically.", func() {
+			// Delete the managedCluster
+			err := util.DeleteClusterResource(dynamicClient, util.ManagedClusterGVR, testManagedClusterName)
+			gomega.Expect(err).ShouldNot(gomega.HaveOccurred())
+
 			gomega.Eventually(func() bool {
 				existing, err := util.HasResource(dynamicClient, clusterInfoGVR, testManagedClusterName, testManagedClusterName)
 				if err != nil {
