@@ -11,8 +11,8 @@ import (
 	velerov1 "github.com/heptio/velero/pkg/apis/velero/v1"
 	corev1 "k8s.io/api/core/v1"
 
-	"github.com/openshift/hive/pkg/apis"
-	hivev1 "github.com/openshift/hive/pkg/apis/hive/v1"
+	"github.com/openshift/hive/apis"
+	hivev1 "github.com/openshift/hive/apis/hive/v1"
 	controllerutils "github.com/openshift/hive/pkg/controller/utils"
 	testcheckpoint "github.com/openshift/hive/pkg/test/checkpoint"
 	testclusterdeployment "github.com/openshift/hive/pkg/test/clusterdeployment"
@@ -71,7 +71,7 @@ func TestNewReconciler(t *testing.T) {
 			test.setup()
 
 			// Act
-			tmpResult, actualError := NewReconciler(mockManager)
+			tmpResult, actualError := NewReconciler(mockManager, nil)
 			actualResult := tmpResult.(*ReconcileBackup)
 
 			// Assert
@@ -271,7 +271,7 @@ func TestReconcile(t *testing.T) {
 			tolerance := float64(10 * time.Second)
 
 			// Act
-			actualResult, actualError := r.Reconcile(test.request)
+			actualResult, actualError := r.Reconcile(context.TODO(), test.request)
 			actualObjects, err := controllerutils.ListRuntimeObjects(r, types, client.InNamespace(namespace))
 			lastBackupName, lastBackupTimestamp := ignoreUncomparedFields(test.expectedObjects, actualObjects)
 
